@@ -64,9 +64,9 @@ class InteractiveTable(widgets.DOMWidget):
     _model_module = _Unicode('ipydatatable').tag(sync=True)
 
     # Version of the front-end module containing widget view
-    _view_module_version = _Unicode('^1.0.0').tag(sync=True)
+    _view_module_version = _Unicode('^1.0.2').tag(sync=True)
     # Version of the front-end module containing widget model
-    _model_module_version = _Unicode('^1.0.0').tag(sync=True)
+    _model_module_version = _Unicode('^1.0.2').tag(sync=True)
 
     # Widget specific property.
     # Widget properties are defined as traitlets. Any property tagged with `sync=True`
@@ -78,6 +78,7 @@ class InteractiveTable(widgets.DOMWidget):
     text_limit = _Int(1000).tag(sync=True)
     sort_column = _Unicode("None").tag(sync=True)
     selected_group = _DataTable([]).tag(sync=True)
+    set_selected_group_bool = _Int(0).tag(sync=True)
     selected_data = _DataTable([]).tag(sync=True)
     selected_index_row = _DataTable([]).tag(sync=True)
     columns = _DataTable([]).tag(sync=True)
@@ -141,3 +142,15 @@ class InteractiveTable(widgets.DOMWidget):
                 data[split[0]] = {split[1]:split[2]}
                 
         return data
+
+    def set_selected_groups(self, value):
+        self.selected_group = value
+        data = {}
+        for x in value:
+            split = x.split(":")
+            if split[0] in data.keys():
+                data[split[0]][split[1]] = split[2]
+            else:
+                data[split[0]] = {split[1]:split[2]}
+                
+        return data
\ No newline at end of file
