@@ -14,7 +14,6 @@ var widgets = require('@jupyter-widgets/base');
 window.$ = window.jQuery = require( 'jquery' );
 var dt = require( 'datatables.net' ); 
 
-
 window.pdfMake = require('pdfmake/build/pdfmake.min');
 var vfs = require('pdfmake/build/vfs_fonts');
 window.pdfMake.vfs = vfs.pdfMake.vfs;
@@ -37,9 +36,6 @@ var _ = require('lodash');
 // CSS Lab reuirements that would otherwise break Notebook.
 if(lab){
   require('fontawesome');
-  require('!style-loader!css-loader!bootstrap/dist/css/bootstrap.min.css');
-  require( 'bootstrap' );
-  
 }
 
 // Load datatables styles
@@ -56,9 +52,8 @@ var InteractiveTableModel = widgets.DOMWidgetModel.extend({
         _view_name : 'InteractiveTableView',
         _model_module : 'ipydatatable',
         _view_module : 'ipydatatable',
-        _model_module_version : '1.0.0',
-        _view_module_version : '1.0.0',
-        table : []
+        _model_module_version : '1.0.2',
+        _view_module_version : '1.0.2',
     })
 });
 
@@ -77,6 +72,13 @@ var InteractiveTableView = widgets.DOMWidgetView.extend({
       // Selected data variable.
       self.selected_data = []
 
+      //self.model.on('change:selected_data', this.selected_data_changed, this);
+      self.model.on('change:selected_index_row', this.selected_index_row_changed, this);
+      self.model.on('change:selected_group', this.selected_group_changed, this);
+
+      self.onclickRowSelection = false;
+      self.groupClick = false;
+
       // Creating a wrapper element
       self.wrapper = document.createElement('div');
       self.wrapper.id = "wrapper_"+self.cid;
@@ -214,7 +216,7 @@ var InteractiveTableView = widgets.DOMWidgetView.extend({
 
         // Add event listener for opening and closing details
         $('#example_'+self.cid+' tbody').on('click', 'td.show_details', function(){
-          var column_index = table.columns().header().toArray().map(x => x.innerText)
+          var column_index = self.table.columns().header().toArray().map(x => x.innerText)
 
           // Child on click
           function format ( d, index ) {
@@ -262,9 +264,6 @@ var InteractiveTableView = widgets.DOMWidgetView.extend({
                 }else{
                   let label = document.createElement('label');
                   label.style.marginRight = '10px'
-                  label.classList.add('btn');
-                  label.classList.add('btn-primary'); 
-                  label.classList.add('group-buttons'); 
 
                   let input = document.createElement('input');
                   input.setAttribute("type","checkbox");
@@ -275,15 +274,14 @@ var InteractiveTableView = widgets.DOMWidgetView.extend({
                   let selected_group = [...self.model.get("selected_group")];
                   $.each(selected_group,function(i_group, item_group){
                     if(item_group == index+":"+i+":"+value){
-                      label.classList.add('active'); 
+                     input.checked=true;
                     }
                   });
                   
-                  label.appendChild(input);
-                  label.appendChild(document.createTextNode(value));
-                  label.onclick = function(){
+                  
+                  input.onclick = function(){
                     let selected_group = [...self.model.get("selected_group")];
-                    
+                    self.groupClick = true;
                     if(selected_group.indexOf(index+":"+i+":"+value)<0){
                       selected_group.push(index+":"+i+":"+value);
                       self.model.set('selected_group', selected_group);
@@ -295,6 +293,8 @@ var InteractiveTableView = widgets.DOMWidgetView.extend({
                       self.touch();
                     }
                   }
+                  label.appendChild(input);
+                  label.appendChild(document.createTextNode(" "+value));
                   btn_group.appendChild(label);
                 }
               })
@@ -310,16 +310,16 @@ var InteractiveTableView = widgets.DOMWidgetView.extend({
           }
 
           // changing the clicky thing
-          if(table.cell( this ).data() == "-"){
-            table.cell( this ).data("+")
+          if(self.table.cell( this ).data() == "-"){
+            self.table.cell( this ).data("+")
           }
           else{
-            table.cell( this ).data("-")
+            self.table.cell( this ).data("-")
           }
 
           // Getting the proper row.
           var tr = $(this).closest('tr');
-          var row = table.row( tr );
+          var row = self.table.row( tr );
 
           if(row.child.isShown()){
               // This row is already open - close it
@@ -341,15 +341,18 @@ var InteractiveTableView = widgets.DOMWidgetView.extend({
         self.selected = [...self.model.get("selected_index_row")];
         // Selecting a row action
         $('#example_'+self.cid+' tbody').on( 'click', 'tr', function () {
+            console.log(self.table)
             var temp = []
-            if(self.selected.includes(table.row( this ).index() )){
-              self.selected.splice(self.selected.indexOf(table.row( this ).index() ),1)
+            if(self.selected.includes(self.table.row( this ).index() )){
+              self.selected.splice(self.selected.indexOf(self.table.row( this ).index() ),1)
             }else{
-              self.selected.push(table.row( this ).index() );
+              self.selected.push(self.table.row( this ).index() );
             }
             $.each(self.selected,(i, value)=>{
               temp.push(table_data[value])
             })
+            self.onclickRowSelection = true;
+            self.touch();
             self.model.set('selected_data', temp);
             self.model.set('selected_index_row', [...self.selected]);
             self.touch();
@@ -367,8 +370,8 @@ var InteractiveTableView = widgets.DOMWidgetView.extend({
             $(this).html( '<input type="text" placeholder="Search '+title+'" />' );
             // Adding the search mechanism
             $( 'input', this ).on( 'keyup change clear', function () {
-                if ( table.column(self.column_order.indexOf(i+1)).search() !== this.value ) {
-                    table
+                if ( self.table.column(self.column_order.indexOf(i+1)).search() !== this.value ) {
+                  self.table
                         .column(self.column_order.indexOf(i+1))
                         .search( this.value )
                         .draw();
@@ -397,7 +400,7 @@ var InteractiveTableView = widgets.DOMWidgetView.extend({
         });
 
         // Creating table object
-        var table = $('#example_'+self.cid).DataTable({
+        self.table = $('#example_'+self.cid).DataTable({
           dom: 'Blfrtip',
           buttons: [
             {
@@ -476,13 +479,13 @@ var InteractiveTableView = widgets.DOMWidgetView.extend({
         $.each(self.model.get("selected_index_row"),(index, val) => {
           selected_data.push(self.model.get("table")[val])
           
-          table.row( val ).select()
+          self.table.row( val ).select()
         })
         self.model.set('selected_data', selected_data);
         self.touch();
         // Ending selection data
         
-        table.on( 'column-reorder', function ( e, settings, details ) {
+        self.table.on( 'column-reorder', function ( e, settings, details ) {
           var curr = details.mapping;
 
           var temp = []
@@ -499,10 +502,73 @@ var InteractiveTableView = widgets.DOMWidgetView.extend({
           self.wrapper.style.width = (document.getElementById("wrapper_"+self.cid).parentNode.parentNode.parentNode.parentElement.clientWidth-100)+"px";
           self.wrapper.style.setProperty('color', 'black', 'important');
         }        
-        table.columns.adjust();
+        self.table.columns.adjust();
       } );
     },
 
+    selected_group_changed: function (){
+      let self = this;
+      let data = [...self.model.get('selected_group')];
+      let table = $('#example_'+self.cid).DataTable();
+      if (!self.groupClick){
+        table.rows().every( function ( rowIdx, tableLoop, rowLoop ) {
+          let d = this.data();
+          console.log("Data: ",d)
+          
+          if(d[0] == "-"){
+            d[0] = "+"
+            this.data(d);
+          }
+          
+          this.invalidate();
+      
+          let child = table.row( this ).child;
+
+          if ( child.isShown() ) {
+              child.hide();
+          }
+          
+        } );  
+
+        table 
+          .rows( '.selected' )
+          .nodes()
+          .to$() 
+          .removeClass( 'selected' );  
+
+        table.draw();
+        self.touch();
+      }
+    },
+
+    selected_index_row_changed: function (){
+      let self = this;
+      console.log(self.model.get('selected_index_row'));
+      let table = $('#example_'+self.cid).DataTable();
+      // Initalizing the selection of the data on the table.
+      let selected_data = []
+      if (!self.onclickRowSelection){
+        console.log(table)
+        table 
+          .rows( '.selected' )
+          .nodes()
+          .to$() 
+          .removeClass( 'selected' );
+
+        $.each(self.model.get("selected_index_row"),(index, val) => {
+          selected_data.push(self.model.get("table")[val])
+          
+          table.row( val ).select()
+        })
+        self.model.set('selected_data', selected_data);
+        self.touch();
+      }else{
+        self.onclickRowSelection = false;
+      }
+      self.groupClick = false;
+      // Ending selection data
+    },
+
     create_style_jinteractive: function(){
       if(lab){
         var fa = 'Font Awesome\ 5 Free'
